@@ -1,15 +1,47 @@
 package Proc::tored;
 # ABSTRACT: Service management using a pid file and signals
-$Proc::tored::VERSION = '0.04';
+$Proc::tored::VERSION = '0.05';
 use strict;
 use warnings;
 require Exporter;
 require Proc::tored::Manager;
 
+
+use parent 'Exporter';
+
+our @EXPORT = qw(
+  service
+  in
+  run
+  stop
+  running
+  zap
+);
+
+sub service ($%)  { Proc::tored::Manager->new(name => shift, @_) }
+sub in      ($;@) { dir => shift, @_ }
+sub run     (&$)  { $_[1]->service($_[0]) }
+sub stop    ($)   { $_[0]->stop }
+sub pid     ($)   { $_[0]->read_pid }
+sub running ($)   { $_[0]->running_pid }
+sub zap     ($;@) { shift->stop_running_process(@_) }
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Proc::tored - Service management using a pid file and signals
 
+=head1 VERSION
+
+version 0.05
+
 =head1 SYNOPSIS
 
   use Proc::tored;
@@ -84,24 +116,36 @@ seconds for the process to exit.
   zap $service, 30
     or die 'timed out after 30s waiting for service to exit';
 
+=head1 CAVEATS
+
+=head2 Threads
+
+A C<Proc::tored> service voluntarily self-terminates when it receives one of
+C<SIGTERM>, C<SIGINT>, C<SIGHUP>, or C<SIGPIPE>. On threaded perls, only the
+main thread receives signals. It is highly likely that a C<Proc::tored> service
+started outside the main thread will not respond to being L</zap>ped by another
+process.
+
+See B<catching signals> under L<http://perldoc.perl.org/threads.html#WARNINGS>
+for details.
+
+=head2 MSWin32
+
+The same warnings about threads apply to forked processes on MSWin32 perls as
+a result of C<fork()> being implemented using threads on that platform.
+
+See the notes regarding pseudoprocesses under
+L<http://perldoc.perl.org/perlfork.html#kill()>.
+
+=head1 AUTHOR
+
+Jeff Ober <jeffober@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Jeff Ober.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-use parent 'Exporter';
-
-our @EXPORT = qw(
-  service
-  in
-  run
-  stop
-  running
-  zap
-);
-
-sub service ($%)  { Proc::tored::Manager->new(name => shift, @_) }
-sub in      ($;@) { dir => shift, @_ }
-sub run     (&$)  { $_[1]->service($_[0]) }
-sub stop    ($)   { $_[0]->stop }
-sub running ($)   { $_[0]->running_pid }
-sub zap     ($;@) { shift->stop_running_process(@_) }
-
-1;
