@@ -1,9 +1,190 @@
 package Proc::tored::Manager;
 # ABSTRACT: OO interface to creating a proctored service
-$Proc::tored::Manager::VERSION = '0.04';
+$Proc::tored::Manager::VERSION = '0.05';
+
+use strict;
+use warnings;
+use Moo;
+use Carp;
+use Fcntl qw(:flock :seek :DEFAULT);
+use Guard qw(guard scope_guard);
+use Path::Tiny qw(path);
+use Time::HiRes qw(sleep);
+use Try::Tiny;
+use Type::Utils qw(declare as where);
+use Types::Standard qw(Str Bool Num is_CodeRef);
+
+my $NonEmptyStr = declare, as Str, where { $_ =~ /\S/ };
+my $Directory = declare, as $NonEmptyStr, where { -d $_ };
+
+with 'Proc::tored::Role::Running';
+
+
+has dir => (
+  is  => 'ro',
+  isa => $Directory,
+  required => 1,
+);
+
+has name => (
+  is  => 'ro',
+  isa => $NonEmptyStr,
+  required => 1,
+);
+
+
+has filepath => (
+  is  => 'lazy',
+  isa => $NonEmptyStr,
+  init_arg => undef,
+);
+
+sub _build_filepath {
+  my $self = shift;
+  sprintf '%s/%s.pid', $self->dir, $self->name;
+}
+
+
+
+sub service {
+  my ($self, $code) = @_;
+  die 'expected a CODE ref' unless is_CodeRef($code);
+
+  if (my $guard = $self->run_lock) {
+    while ($self->is_running && $code->()) {
+      ;
+    }
+
+    return 1;
+  }
+
+  return 0;
+}
+
+
+sub read_pid {
+  my $self = shift;
+  my $file = path($self->filepath);
+  return 0 unless $file->is_file;
+  my ($line) = $file->lines({count => 1, chomp => 1}) or return 0;
+  my ($pid) = $line =~ /^(\d+)$/;
+  return $pid || 0;
+}
+
+
+sub running_pid {
+  my $self = shift;
+  my $pid = $self->read_pid;
+  return 0 unless $pid;
+  return $pid if kill 0, $pid;
+  return 0;
+}
+
+
+sub stop_running_process {
+  my ($self, $timeout, $sleep) = @_;
+  $sleep ||= 0.2;
+
+  my $pid = $self->running_pid || return 0;
+  return $self->stop if $pid == $$;
+
+  if (kill('TERM', $pid) > 0) {
+    if ($timeout) {
+      while (kill(0, $pid) && $timeout > 0) {
+        sleep $sleep;
+        $timeout -= $sleep;
+      }
+    }
+  }
+
+  !kill(0, $pid);
+}
+
+
+sub run_lock {
+  my $self = shift;
+  return if $self->running_pid;
+
+  my $file = path($self->filepath);
+
+  # Write pid to the pidfile
+  if ($self->with_lock(sub { $file->spew("$$\n") })) {
+    $self->start;
+
+    # Create guard object that releases the pidfile once out of scope
+    return guard {
+      $self->stop;
+      $file->append({truncate => 1});
+    };
+  }
+
+  return;
+}
+
+#-------------------------------------------------------------------------------
+# Calls $code while holding the lock, unlocking afterward. Returns true when
+# the lock is achieved and $code is called.
+#-------------------------------------------------------------------------------
+sub with_lock {
+  my ($self, $code) = @_;
+  my $lock = $self->_lock or return;
+  $code->();
+  undef $lock;
+  return 1;
+}
+
+#-------------------------------------------------------------------------------
+# Creates a .lock file based on $self->filepath. While the file exists, the
+# lock is considered to be held. Returns a Guard that removes the file.
+#-------------------------------------------------------------------------------
+sub _lock {
+  my $self = shift;
+
+  # Existing .lock file means another process came in ahead
+  my $lock = path($self->filepath . '.lock');
+  return if $lock->exists;
+
+  my $locked = try {
+      $lock->filehandle({exclusive => 1}, '>');
+    }
+    catch {
+      # Rethrow if error was something other than the file already existing.
+      # Assume any 'sysopen' error matching 'File exists' is an indication
+      # of that.
+      die $_
+        unless $_->{op} eq 'sysopen' && $_->{err} =~ /File exists/i
+            || $lock->exists;
+    };
+
+  return unless $locked;
+  return guard { $self->_unlock };
+}
+
+#-------------------------------------------------------------------------------
+# Removes the .lock file.
+#-------------------------------------------------------------------------------
+sub _unlock {
+  my $self = shift;
+  my $lock = path($self->filepath . '.lock');
+  try { $lock->remove }
+  catch { carp "unable to remove lock file: $_" }
+}
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Proc::tored::Manager
+Proc::tored::Manager - OO interface to creating a proctored service
+
+=head1 VERSION
+
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -23,25 +204,6 @@ Proc::tored::Manager
 
 Objective interface for creating and managing a proctored service.
 
-=cut
-
-use strict;
-use warnings;
-use Moo;
-use Carp;
-use Fcntl qw(:flock :seek :DEFAULT);
-use Guard qw(guard scope_guard);
-use Path::Tiny qw(path);
-use Time::HiRes qw(sleep);
-use Try::Tiny;
-use Type::Utils qw(declare as where);
-use Types::Standard qw(Str Bool Num is_CodeRef);
-
-my $NonEmptyStr = declare, as Str, where { $_ =~ /\S/ };
-my $Directory = declare, as $NonEmptyStr, where { -d $_ };
-
-with 'Proc::tored::Role::Running';
-
 =head1 METHODS
 
 =head2 new
@@ -64,44 +226,15 @@ file is to be found.
 
 =back
 
-=cut
-
-has dir => (
-  is  => 'ro',
-  isa => $Directory,
-  required => 1,
-);
-
-has name => (
-  is  => 'ro',
-  isa => $NonEmptyStr,
-  required => 1,
-);
-
 =head2 filepath
 
 Returns the file system path created by concatenating the values of C<dir> and
 C<name> that were passed to C<new>.
 
-=cut
-
-has filepath => (
-  is  => 'lazy',
-  isa => $NonEmptyStr,
-  init_arg => undef,
-);
-
-sub _build_filepath {
-  my $self = shift;
-  sprintf '%s/%s.pid', $self->dir, $self->name;
-}
-
 =head2 is_running
 
 See L<Proc::tored::Role::Running/is_running>.
 
-=cut
-
 =head2 service
 
 Accepts a code ref which will be called repeatedly until it or L</is_running>
@@ -137,52 +270,28 @@ built-in signal handlers):
     return 1;
   });
 
-=cut
-
-sub service {
-  my ($self, $code) = @_;
-  die 'expected a CODE ref' unless is_CodeRef($code);
-
-  if (my $guard = $self->run_lock) {
-    while ($self->is_running && $code->()) {
-      ;
-    }
-
-    return 1;
-  }
-
-  return 0;
-}
-
-=head2 running_pid
+=head2 read_pid
 
 Returns the pid identified in the pid file. Returns 0 if the pid file does
 not exist or is empty.
 
-=cut
+=head2 running_pid
 
-sub running_pid {
-  my $self = shift;
-  my $file = path($self->filepath);
-  return 0 unless $file->is_file;
-  my ($line) = $file->lines({count => 1, chomp => 1}) or return 0;
-  my ($pid) = $line =~ /^(\d+)$/;
-  return $pid || 0;
-}
+Returns the pid of an already-running process or 0 if the pid file does not
+exist, is empty, or the process identified by the pid does not exist or is not
+visible.
 
 =head2 stop_running_process
 
-See L<Proc::tored::Role::Running/stop_running_process>. When called from this
-class, the C<$pid> parameter is provided via L</running_pid>.
+Issues a C<SIGTERM> to the active process. Returns 0 immediately if the pid
+file does not exist or is empty. Otherwise, polls the running process until the
+OS reports that it is no longer able to receive signals (with `kill(0, $pid)`).
 
-=cut
+Optional parameter C<$timeout> may be specified in fractional seconds, causing
+C<stop_running_process> to block up to (around) C<$timeout> seconds waiting for
+the signaled process to exit.
 
-around stop_running_process => sub {
-  my $orig = shift;
-  my $self = shift;
-  my $pid  = $self->running_pid or return 0;
-  return $self->$orig($pid, @_);
-};
+Returns the pid of the completed process otherwise.
 
 =head2 run_lock
 
@@ -196,45 +305,15 @@ lock once out of scope. Returns undef otherwise.
 
 L</service> is preferred to this method for most uses.
 
+=head1 AUTHOR
+
+Jeff Ober <jeffober@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Jeff Ober.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-sub run_lock {
-  my $self = shift;
-  my $pid = $self->running_pid;
-  $pid && kill(0, $pid) && return; # pid points to running process
-
-  # existing .lock file means another process came in ahead
-  my $lock = path($self->filepath . '.lock');
-  return if $lock->exists;
-
-  my $locked = try {
-      $lock->filehandle({exclusive => 1}, '>');
-    }
-    catch {
-      # Rethrow if error was something other than the file already existing.
-      # Assume any 'sysopen' error matching 'File exists' is an indication
-      # of that.
-      die $_
-        unless $_->{op} eq 'sysopen' && $_->{err} =~ /File exists/i
-            || $lock->exists;
-    };
-
-  return unless $locked;
-
-  # remove the lock file when out of scope
-  scope_guard { $lock->remove };
-
-  # write pid to the pidfile
-  my $file = path($self->filepath);
-  $file->spew("$$\n");
-
-  $self->start;
-
-  # Create guard object that releases the pidfile once out of scope
-  return guard {
-    $self->stop;
-    $file->append({truncate => 1});
-  };
-}
-
-1;
